@@ -6,19 +6,20 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
+#include "connection.h"
 #include "device_p.h"
 #include "manager.h"
 #include "manager_p.h"
-#include "connection.h"
-#include "settings.h"
 #include "nmdebug.h"
+#include "settings.h"
 
 #include <arpa/inet.h>
 
+#include <QDBusMetaType>
 #include <QDBusObjectPath>
 
 // logging category for this framework, default: log stuff >= warning
-Q_LOGGING_CATEGORY(NMQT, "networkmanager-qt", QtWarningMsg)
+Q_LOGGING_CATEGORY(NMQT, "kf.networkmanagerqt", QtWarningMsg)
 
 namespace NetworkManager
 {
@@ -28,11 +29,13 @@ public:
     DeviceStateReasonPrivate(Device::State st, Device::StateChangeReason rsn)
         : state(st)
         , reason(rsn)
-    {}
+    {
+    }
     DeviceStateReasonPrivate()
         : state(Device::UnknownState)
         , reason(Device::UnknownReason)
-    {}
+    {
+    }
     Device::State state;
     Device::StateChangeReason reason;
 };
@@ -81,6 +84,7 @@ NetworkManager::DevicePrivate::DevicePrivate(const QString &path, NetworkManager
 #endif
     , uni(path)
     , designSpeed(0)
+    , deviceType(Device::UnknownType)
     , dhcp4Config(nullptr)
     , dhcp6Config(nullptr)
     , mtu(0)
@@ -103,9 +107,14 @@ void NetworkManager::DevicePrivate::init()
     qDBusRegisterMetaType<IpV6DBusRouteList>();
     qDBusRegisterMetaType<DeviceDBusStateReason>();
 
-    // This needs to be initialized as soon as possible, because based on this property
-    // we initialize the device type
-    deviceType = convertType(deviceIface.deviceType());
+    QDBusConnection::systemBus().connect(NetworkManagerPrivate::DBUS_SERVICE,
+                                         uni,
+                                         NetworkManagerPrivate::FDO_DBUS_PROPERTIES,
+                                         QLatin1String("PropertiesChanged"),
+                                         this,
+                                         SLOT(dbusPropertiesChanged(QString, QVariantMap, QStringList)));
+    QObject::connect(&deviceIface, &OrgFreedesktopNetworkManagerDeviceInterface::StateChanged, this, &DevicePrivate::deviceStateChanged);
+
 
     deviceStatistics = DeviceStatistics::Ptr(new NetworkManager::DeviceStatistics(uni), &QObject::deleteLater);
 
@@ -115,19 +124,17 @@ void NetworkManager::DevicePrivate::init()
         propertiesChanged(initialProperties);
     }
 
-    QObject::connect(&deviceIface, &OrgFreedesktopNetworkManagerDeviceInterface::StateChanged, this, &DevicePrivate::deviceStateChanged);
 }
 
 NetworkManager::Device::MeteredStatus NetworkManager::DevicePrivate::convertMeteredStatus(uint metered)
 {
-    NetworkManager::Device::MeteredStatus ourMeteredStatus = (NetworkManager::Device::MeteredStatus) metered;
+    NetworkManager::Device::MeteredStatus ourMeteredStatus = (NetworkManager::Device::MeteredStatus)metered;
     return ourMeteredStatus;
 }
 
 NetworkManager::Device::Capabilities NetworkManager::DevicePrivate::convertCapabilities(uint theirCaps)
 {
-    NetworkManager::Device::Capabilities ourCaps
-        = (NetworkManager::Device::Capabilities) theirCaps;
+    NetworkManager::Device::Capabilities ourCaps = (NetworkManager::Device::Capabilities)theirCaps;
     return ourCaps;
 }
 
@@ -210,7 +217,7 @@ NetworkManager::Device::Device(const QString &path, QObject *parent)
     d->init();
 }
 
-NetworkManager::Device::Device(DevicePrivate &dd,  QObject *parent)
+NetworkManager::Device::Device(DevicePrivate &dd, QObject *parent)
     : QObject(parent)
     , d_ptr(&dd)
 {
@@ -234,7 +241,7 @@ void NetworkManager::DevicePrivate::propertyChanged(const QString &property, con
         Q_EMIT q->autoconnectChanged();
     } else if (property == QLatin1String("AvailableConnections")) {
         QStringList newAvailableConnections;
-        const QList<QDBusObjectPath> availableConnectionsTmp = qdbus_cast< QList<QDBusObjectPath> >(value);
+        const QList<QDBusObjectPath> availableConnectionsTmp = qdbus_cast<QList<QDBusObjectPath>>(value);
         for (const QDBusObjectPath &availableConnection : availableConnectionsTmp) {
             newAvailableConnections << availableConnection.path();
             if (!availableConnections.contains(availableConnection.path())) {
@@ -257,7 +264,7 @@ void NetworkManager::DevicePrivate::propertyChanged(const QString &property, con
         capabilities = NetworkManager::DevicePrivate::convertCapabilities(value.toUInt());
         Q_EMIT q->capabilitiesChanged();
     } else if (property == QLatin1String("DeviceType")) {
-        deviceType = static_cast<Device::Type>(value.toUInt());
+        deviceType = convertType(value.toUInt());
     } else if (property == QLatin1String("Dhcp4Config")) {
         QDBusObjectPath dhcp4ConfigPathTmp = value.value<QDBusObjectPath>();
         if (dhcp4ConfigPathTmp.path().isNull()) {
@@ -340,8 +347,8 @@ void NetworkManager::DevicePrivate::propertyChanged(const QString &property, con
         physicalPortId = value.toString();
         Q_EMIT q->physicalPortIdChanged();
     } else if (property == QLatin1String("Mtu")) {
-            mtu = value.toUInt();
-            Q_EMIT q->mtuChanged();
+        mtu = value.toUInt();
+        Q_EMIT q->mtuChanged();
     } else if (property == QLatin1String("NmPluginMissing")) {
         nmPluginMissing = value.toBool();
         Q_EMIT q->nmPluginMissingChanged(nmPluginMissing);
@@ -406,7 +413,7 @@ NetworkManager::Connection::List NetworkManager::Device::availableConnections()
     Q_D(const Device);
 
     NetworkManager::Connection::List list;
-    for (const QString &availableConnection : qAsConst(d->availableConnections)) {
+    for (const QString &availableConnection : std::as_const(d->availableConnections)) {
         NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(availableConnection);
         if (connection) {
             list << connection;
@@ -497,10 +504,12 @@ NetworkManager::Dhcp6Config::Ptr NetworkManager::Device::dhcp6Config() const
 bool NetworkManager::Device::isActive() const
 {
     Q_D(const Device);
+    /* clang-format off */
     return !(d->connectionState == NetworkManager::Device::Unavailable
              || d->connectionState == NetworkManager::Device::Unmanaged
              || d->connectionState == NetworkManager::Device::Disconnected
              || d->connectionState == NetworkManager::Device::Failed);
+    /* clang-format on */
 }
 
 bool NetworkManager::Device::isValid() const
@@ -525,7 +534,6 @@ bool NetworkManager::Device::nmPluginMissing() const
 {
     Q_D(const Device);
     return d->nmPluginMissing;
-
 }
 
 NetworkManager::Device::MeteredStatus NetworkManager::Device::metered() const
@@ -598,7 +606,8 @@ void NetworkManager::DevicePrivate::deviceStateChanged(uint newState, uint oldSt
 void NetworkManager::DevicePrivate::dbusPropertiesChanged(const QString &interfaceName, const QVariantMap &properties, const QStringList &invalidatedProperties)
 {
     Q_UNUSED(invalidatedProperties);
-    if (interfaceName.contains(QLatin1String("org.freedesktop.NetworkManager.Device")) && interfaceName != QLatin1String("org.freedesktop.NetworkManager.Device.Statistics")) {
+    if (interfaceName.contains(QLatin1String("org.freedesktop.NetworkManager.Device"))
+        && interfaceName != QLatin1String("org.freedesktop.NetworkManager.Device.Statistics")) {
         propertiesChanged(properties);
     }
 }
@@ -627,3 +636,6 @@ NetworkManager::Device::Type NetworkManager::Device::type() const
     Q_D(const Device);
     return d->deviceType;
 }
+
+#include "moc_device.cpp"
+#include "moc_device_p.cpp"
